@@ -3,9 +3,12 @@ from typing import Optional
 from MSApi.Assortment import Assortment
 from MSApi.ObjectMS import check_init
 from MSApi.ProductFolder import ProductFolder
+from MSApi.mixin import AttributeMixin
 
 
-class Bundle(Assortment):
+class Bundle(Assortment, AttributeMixin):
+
+    _type_name = 'bundle'
 
     def __init__(self, json):
         super().__init__(json)
