@@ -20,6 +20,19 @@ def string_to_datetime(string):
     return value
 
 
+def caching(f):
+    cache = [None]
+
+    def decorate(cls, cached=False, *args, **kwargs):
+        if cached is True:
+            if cache[0] is None:
+                cache[0] = list(f(cls, *args, **kwargs))
+            return (a for a in cache[0])
+        else:
+            return f(cls, *args, **kwargs)
+    return decorate
+
+
 class Authorizer:
     token = None
 
@@ -82,7 +95,6 @@ class MSLowApi:
                                      "Content-Type": "application/json"},
                             **kwargs)
 
-
     @classmethod
     # @check_login
     def _auch_get_by_href(cls, request,
@@ -110,3 +122,32 @@ class MSLowApi:
                             headers={"Authorization": f"Bearer {cls.__authorizer.token}",
                                      "Content-Type": "application/json"},
                             **kwargs)
+
+    @classmethod
+    def gen_objects(cls, request, obj, limit: int = None, expand: Expand = None, **kwargs):
+
+        local_limit = 1000
+        if limit is not None and limit < 1000:
+            local_limit = limit
+
+        if expand is not None:
+            local_limit = 100
+
+        offset = 0
+        while True:
+            response = cls.auch_get(request, limit=local_limit, offset=offset, expand=expand, **kwargs)
+            error_handler(response)
+            row_counter = 0
+            for row in response.json().get('rows'):
+                yield obj(row)
+                row_counter += 1
+            if row_counter == 0:
+                break
+            offset += local_limit
+            if limit is None:
+                continue
+            limit -= local_limit
+            if limit < local_limit:
+                local_limit = limit
+            if local_limit == 0:
+                break
