@@ -1,11 +1,14 @@
 from typing import Optional
 
+from MSApi.mixin.AttributeMixin import AttributeMixin
 from MSApi.Assortment import Assortment
 from MSApi.ProductFolder import ProductFolder
 from MSApi.ObjectMS import check_init
 
 
-class Product(Assortment):
+class Product(Assortment, AttributeMixin):
+
+    _type_name = 'product'
 
     def __init__(self, json):
         super().__init__(json)
